@@ -104,7 +104,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 """
 import abc
 import builtins
@@ -172,42 +172,42 @@ class KinesisStreamsToKinesisFirehoseToS3(
 
         jsii.create(KinesisStreamsToKinesisFirehoseToS3, self, [scope, id, props])
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="kinesisFirehose")
     def kinesis_firehose(self) -> aws_cdk.aws_kinesisfirehose.CfnDeliveryStream:
-        return jsii.get(self, "kinesisFirehose")
+        return typing.cast(aws_cdk.aws_kinesisfirehose.CfnDeliveryStream, jsii.get(self, "kinesisFirehose"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="kinesisFirehoseLogGroup")
     def kinesis_firehose_log_group(self) -> aws_cdk.aws_logs.LogGroup:
-        return jsii.get(self, "kinesisFirehoseLogGroup")
+        return typing.cast(aws_cdk.aws_logs.LogGroup, jsii.get(self, "kinesisFirehoseLogGroup"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="kinesisFirehoseRole")
     def kinesis_firehose_role(self) -> aws_cdk.aws_iam.Role:
-        return jsii.get(self, "kinesisFirehoseRole")
+        return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "kinesisFirehoseRole"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="kinesisStream")
     def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
-        return jsii.get(self, "kinesisStream")
+        return typing.cast(aws_cdk.aws_kinesis.Stream, jsii.get(self, "kinesisStream"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
     ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
-        return jsii.get(self, "cloudwatchAlarms")
+        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="s3Bucket")
     def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
-        return jsii.get(self, "s3Bucket")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3Bucket"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="s3LoggingBucket")
     def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
-        return jsii.get(self, "s3LoggingBucket")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3LoggingBucket"))
 
 
 @jsii.data_type(
@@ -274,7 +274,7 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         :default: - Default props are used
         """
         result = self._values.get("bucket_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
 
     @builtins.property
     def create_cloud_watch_alarms(self) -> typing.Optional[builtins.bool]:
@@ -283,7 +283,7 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         :default: - Alarms are created
         """
         result = self._values.get("create_cloud_watch_alarms")
-        return result
+        return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
@@ -292,7 +292,7 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         :default: - None
         """
         result = self._values.get("existing_bucket_obj")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.IBucket], result)
 
     @builtins.property
     def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
@@ -301,7 +301,7 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         :default: - None
         """
         result = self._values.get("existing_stream_obj")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_kinesis.Stream], result)
 
     @builtins.property
     def kinesis_firehose_props(self) -> typing.Any:
@@ -310,7 +310,7 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         :default: - Default props are used
         """
         result = self._values.get("kinesis_firehose_props")
-        return result
+        return typing.cast(typing.Any, result)
 
     @builtins.property
     def kinesis_stream_props(self) -> typing.Optional[aws_cdk.aws_kinesis.StreamProps]:
@@ -319,7 +319,7 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         :default: - Default props are used.
         """
         result = self._values.get("kinesis_stream_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_kinesis.StreamProps], result)
 
     @builtins.property
     def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
@@ -328,7 +328,7 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         :default: - Default props are used
         """
         result = self._values.get("log_group_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_logs.LogGroupProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
